@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,9 +32,8 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.accessapproval_v1.services.access_approval import pagers
 from google.cloud.accessapproval_v1.types import accessapproval
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import AccessApprovalTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import AccessApprovalGrpcTransport
 from .transports.grpc_asyncio import AccessApprovalGrpcAsyncIOTransport
@@ -57,7 +54,7 @@ class AccessApprovalClientMeta(type):
     _transport_registry["grpc_asyncio"] = AccessApprovalGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[AccessApprovalTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -115,7 +112,8 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -147,10 +145,27 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            AccessApprovalClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -159,7 +174,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            AccessApprovalClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -169,16 +184,17 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
     @property
     def transport(self) -> AccessApprovalTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            AccessApprovalTransport: The transport used by the client instance.
+            AccessApprovalTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -191,7 +207,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -202,7 +218,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -213,7 +229,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -224,7 +240,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -238,12 +254,12 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, AccessApprovalTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the access approval client.
+        """Instantiates the access approval client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -251,10 +267,10 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.AccessApprovalTransport]): The
+            transport (Union[str, AccessApprovalTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (client_options_lib.ClientOptions): Custom options for the
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -290,21 +306,18 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -316,12 +329,14 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -336,8 +351,8 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -347,7 +362,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -367,16 +382,16 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         order is reverse chronological.
 
         Args:
-            request (:class:`~.accessapproval.ListApprovalRequestsMessage`):
+            request (google.cloud.accessapproval_v1.types.ListApprovalRequestsMessage):
                 The request object. Request to list approval requests.
-            parent (:class:`str`):
+            parent (str):
                 The parent resource. This may be
                 "projects/{project_id}", "folders/{folder_id}", or
                 "organizations/{organization_id}".
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -384,7 +399,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListApprovalRequestsPager:
+            google.cloud.accessapproval_v1.services.access_approval.pagers.ListApprovalRequestsPager:
                 Response to listing of
                 ApprovalRequest objects.
                 Iterating over this object will yield
@@ -408,10 +423,8 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         # there are no flattened fields.
         if not isinstance(request, accessapproval.ListApprovalRequestsMessage):
             request = accessapproval.ListApprovalRequestsMessage(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -450,15 +463,15 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         not exist.
 
         Args:
-            request (:class:`~.accessapproval.GetApprovalRequestMessage`):
+            request (google.cloud.accessapproval_v1.types.GetApprovalRequestMessage):
                 The request object. Request to get an approval request.
-            name (:class:`str`):
+            name (str):
                 Name of the approval request to
                 retrieve.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -466,7 +479,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.accessapproval.ApprovalRequest:
+            google.cloud.accessapproval_v1.types.ApprovalRequest:
                 A request for the customer to approve
                 access to a resource.
 
@@ -487,10 +500,8 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         # there are no flattened fields.
         if not isinstance(request, accessapproval.GetApprovalRequestMessage):
             request = accessapproval.GetApprovalRequestMessage(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -525,10 +536,9 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         pending state.
 
         Args:
-            request (:class:`~.accessapproval.ApproveApprovalRequestMessage`):
+            request (google.cloud.accessapproval_v1.types.ApproveApprovalRequestMessage):
                 The request object. Request to approve an
                 ApprovalRequest.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -536,13 +546,12 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.accessapproval.ApprovalRequest:
+            google.cloud.accessapproval_v1.types.ApprovalRequest:
                 A request for the customer to approve
                 access to a resource.
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a accessapproval.ApproveApprovalRequestMessage.
         # There's no risk of modifying the input as we've already verified
@@ -586,10 +595,9 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         a pending state.
 
         Args:
-            request (:class:`~.accessapproval.DismissApprovalRequestMessage`):
+            request (google.cloud.accessapproval_v1.types.DismissApprovalRequestMessage):
                 The request object. Request to dismiss an approval
                 request.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -597,13 +605,12 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.accessapproval.ApprovalRequest:
+            google.cloud.accessapproval_v1.types.ApprovalRequest:
                 A request for the customer to approve
                 access to a resource.
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a accessapproval.DismissApprovalRequestMessage.
         # There's no risk of modifying the input as we've already verified
@@ -640,16 +647,16 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         or organization.
 
         Args:
-            request (:class:`~.accessapproval.GetAccessApprovalSettingsMessage`):
+            request (google.cloud.accessapproval_v1.types.GetAccessApprovalSettingsMessage):
                 The request object. Request to get access approval
                 settings.
-            name (:class:`str`):
+            name (str):
                 Name of the AccessApprovalSettings to
                 retrieve.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -657,7 +664,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.accessapproval.AccessApprovalSettings:
+            google.cloud.accessapproval_v1.types.AccessApprovalSettings:
                 Settings on a
                 Project/Folder/Organization related to
                 Access Approval.
@@ -679,10 +686,8 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         # there are no flattened fields.
         if not isinstance(request, accessapproval.GetAccessApprovalSettingsMessage):
             request = accessapproval.GetAccessApprovalSettingsMessage(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -709,7 +714,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         request: accessapproval.UpdateAccessApprovalSettingsMessage = None,
         *,
         settings: accessapproval.AccessApprovalSettings = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -719,15 +724,15 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         field_mask.
 
         Args:
-            request (:class:`~.accessapproval.UpdateAccessApprovalSettingsMessage`):
+            request (google.cloud.accessapproval_v1.types.UpdateAccessApprovalSettingsMessage):
                 The request object. Request to update access approval
                 settings.
-            settings (:class:`~.accessapproval.AccessApprovalSettings`):
+            settings (google.cloud.accessapproval_v1.types.AccessApprovalSettings):
                 The new AccessApprovalSettings.
                 This corresponds to the ``settings`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (google.protobuf.field_mask_pb2.FieldMask):
                 The update mask applies to the settings. Only the top
                 level fields of AccessApprovalSettings
                 (notification_emails & enrolled_services) are supported.
@@ -739,10 +744,10 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
                 If this field is left unset, only the
                 notification_emails field will be updated.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -750,7 +755,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.accessapproval.AccessApprovalSettings:
+            google.cloud.accessapproval_v1.types.AccessApprovalSettings:
                 Settings on a
                 Project/Folder/Organization related to
                 Access Approval.
@@ -772,10 +777,8 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         # there are no flattened fields.
         if not isinstance(request, accessapproval.UpdateAccessApprovalSettingsMessage):
             request = accessapproval.UpdateAccessApprovalSettingsMessage(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if settings is not None:
                 request.settings = settings
             if update_mask is not None:
@@ -820,16 +823,16 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         inherited.
 
         Args:
-            request (:class:`~.accessapproval.DeleteAccessApprovalSettingsMessage`):
+            request (google.cloud.accessapproval_v1.types.DeleteAccessApprovalSettingsMessage):
                 The request object. Request to delete access approval
                 settings.
-            name (:class:`str`):
+            name (str):
                 Name of the AccessApprovalSettings to
                 delete.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -852,10 +855,8 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         # there are no flattened fields.
         if not isinstance(request, accessapproval.DeleteAccessApprovalSettingsMessage):
             request = accessapproval.DeleteAccessApprovalSettingsMessage(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
